<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use App\Models\City;
use App\Models\Token;
use App\User;
use Edujugon\PushNotification\PushNotification;
use Illuminate\Http\Request;


class UsersController extends Controller
{

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $rows = User::whereType('user')->orderByDesc('id')->get();
        return view('admin.users.index', compact('rows'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $cities = City::all();
        return view('admin.users.create', compact('cities'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validate($request, [
            'name' => 'required',
            'city_id' => 'required|exists:cities,id',
            'email' => 'required|email|unique:users',
            'password' => 'required|min:6',
            'status' => 'required|in:active,not_active',
            'mobile' => 'required|unique:users,mobile',
            'image' => 'image',
            'image_cover' => 'image'

        ]);
        $user = new User();
        $user['name'] = $request['name'];
        $user['email'] = $request['email'];
        $user['whatsapp'] = $request['whatsapp'];
        $user['city_id'] = $request['city_id'];
        $user['mobile'] = $request['mobile'];
        $user['address'] = $request['address'];
        $user['status'] = $request['status'];
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        if ($request->hasFile('image_cover')) {
            $user->setImageCoverAttribute();
        }
        $user['password'] = bcrypt($request['password']);
        $user['type'] = 'user';
        $user->save();

        return redirect()->route('users.index')->with('message', 'تم الانشاء بنجاح');
    }

    /**
     * Display the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $row = User::find($id);
        $cities = City::all();
        return view('admin.users.edit', compact('row', 'cities'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param \Illuminate\Http\Request $request
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $this->validate($request, [
            'name' => 'required',
            'city_id' => 'required|exists:cities,id',
            'email' => 'required|email|unique:users,email,' . $id,
            'mobile' => 'required|unique:users,mobile,' . $id,
            //'password' => 'required|min:6',
            'status' => 'required|in:active,not_active',

            'image' => 'image',
            'image_cover' => 'image'
        ]);

//        $this->sometimes('password', 'min:6|confirmed', function ($input) {
//            return (strlen($input->password) > 0);
//        });
        $user = User::find($id);
        $user['name'] = $request['name'];
        $user['email'] = $request['email'];
        $user['whatsapp'] = $request['whatsapp'];
        $user['city_id'] = $request['city_id'];
        $user['mobile'] = $request['mobile'];
        $user['address'] = $request['address'];
        $user['status'] = $request['status'];
        if ($request->hasFile('image')) {
            $user->setImageAttribute();
        }
        if ($request->hasFile('image_cover')) {
            $user->setImageCoverAttribute();
        }
        if ($request['password']) $user['password'] = bcrypt($request['password']);
        $user['type'] = 'user';
        $user->update();
        return redirect()->route('users.index')->with('message', 'تم التعديل بنجاح');

    }

    /**
     * Remove the specified resource from storage.
     *
     * @param int $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        $user = Slider::find($id);
        $user->deleteImage();
        User::destroy($id);
        return redirect()->back()->with('message', 'تم الحذف بنجاح');
    }


}
