<?php

namespace App\Http\Controllers\Api;

use App\Http\Controllers\Controller;
use App\Http\Resources\BankResource;
use App\Models\Bank;
use App\Models\Setting;
use App\Models\Transfer;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Lang;

class BanksController extends Controller
{

    public function banks(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $setting = Setting::first();
        $banks = Bank::all();
        $data = BankResource::collection($banks);
        return response()->json(['value' => 'true', 'data' => $data, 'commission_building' => $setting->commission_building, 'commission_car' => $setting->commission_car, 'code' => 200]);
    }

    public function calc_commission(Request $request)
    {
        $lang = $request->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'amount' => 'required',
        ]);
        if ($validator->passes()) {
            $setting = Setting::first();

            if ($setting && $setting->commission_car && $setting->commission_building) {
                $data = $request['amount'] - ($request['amount'] - ((integer)$request['amount'] * $setting->commission_car / 100));

            } else {
                $data = $request['amount'] - ($request['amount'] - ($request['amount'] * 1 / 100));
            }
            return response()->json(['value' => true, 'data' => (string)round($data, 2), 'code' => 200]);
        } else {
            return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
        }
    }

    public function transfer(Request $request)
    {
        $lang = \request()->header('Accept-Language', 'ar');
        \App::setLocale($lang);
        $validator = \Validator::make($request->all(), [
            'amount' => 'required',
            'name' => 'required',
            'product_number' => 'required|exists:products,code',
            'name_transfer' => 'required',
            'mobile' => 'required|exists:users,mobile',
            'bank_id' => 'required|exists:banks,id'
        ]);
        if ($validator->passes()) {
            $transfer = new Transfer();
            $transfer->amount = $request->amount;
            $transfer->name = $request->name;
            $transfer->product_number = $request->product_number;
            $transfer->name_transfer = $request->name_transfer;
            $transfer->mobile = $request->mobile;
            $transfer->bank_id = $request->bank_id;
            if ($request->note) {
                $transfer->note = $request->note;
            }
            $transfer->save();
            return response()->json(['value' => true, 'data' => Lang::get('data.transfer_done'), 'code' => 200]);
        }
        return response()->json(['value' => false, 'msg' => $validator->errors()->first(), 'code' => 422]);
    }
}
