<?php

namespace App\Models;

use App\User;
use Illuminate\Database\Eloquent\Model;
use JWTAuth;


class Product extends Model
{

    protected $table = 'products';
    public $timestamps = true;
    protected $fillable = array('title', 'description', 'year','price', 'color', 'km', 'user_id', 'category_id', 'city_id', 'fetis', 'type', 'flag', 'number_seats', 'code', 'size', 'address', 'number_room', 'number_floors');
    protected $appends = ['is_favorite'];

    public function getIsFavoriteAttribute()
    {
        if (request()->header('Authorization')) {

            if (!$user = JWTAuth::parseToken()->authenticate()) {
                return false;
            } else {

                $fav = Favorite::where(['user_id' => $user->id, 'product_id' => $this->id])->first();
                if ($fav) {
                    return true;
                } else {
                    return false;
                }
            }
        }

    }

    public function user()
    {
        return $this->belongsTo(User::class, 'user_id');
    }

    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function category()
    {
        return $this->belongsTo(Category::class, 'category_id');
    }

    public function images()
    {
        return $this->hasMany(ProductImage::class, 'product_id');
    }

    public function reports()
    {
        return $this->hasMany(Report::class, 'product_id');
    }

    public function favorite_users()
    {
        return $this->belongsToMany(User::class, 'favorites', 'product_id', 'user_id');
    }

}
