<?php

namespace App;

use App\Models\Product;
use App\Models\Report;
use Illuminate\Notifications\Notifiable;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Tymon\JWTAuth\Contracts\JWTSubject;
use App\Models\City;

class User extends Authenticatable implements JWTSubject
{
    use Notifiable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array
     */
    protected $table = 'users';
    public $timestamps = true;
    protected $fillable = [
    'name', 'mobile', 'email', 'password', 'city_id', 'type', 'code', 'verification', 'address', 'image', 'image_cover', 'whatsapp'
    ];

    /**
     * The attributes that should be hidden for arrays.
     *
     * @var array
     */
    protected $hidden = [
        'password', 'remember_token',
    ];


    public function city()
    {
        return $this->belongsTo(City::class, 'city_id');
    }

    public function products()
    {
        return $this->hasMany(Product::class, 'user_id');
    }

    public function reports()
    {
        return $this->hasMany(Report::class, 'user_id');
    }

    public function favorites()
    {
        return $this->belongsToMany(Product::class, 'favorites', 'user_id', 'product_id', '');
    }


    public function setImageAttribute()
    {
        $file = request()->file('image');
        $destinationPath = 'images/users/';
        $filename = time().'.'.$file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image'] = $filename;
    }

    // public function getImageAttribute()
    // {
    //     if ($this->attributes['image']) {
    //         return asset('images/users/') . '/' . $this->attributes['image'];
    //     }
    //     return asset('images/users/default.jpg');
    // }

    public function setImageCoverAttribute()
    {
        $file = request()->file('image_cover');
        $destinationPath = 'images/users/';
        $filename = md5(microtime()).'.'.$file->getClientOriginalExtension();
        $file->move($destinationPath, $filename);
        $this->attributes['image_cover'] = $filename;
    }

    // public function getImageCoverAttribute()
    // {
    //     if ($this->attributes['image_cover']) {
    //         return asset('images/users/') . '/' . $this->attributes['image_cover'];
    //     }
    //     return asset('images/users/default.jpg');
    // }



    public function getJWTIdentifier()
    {
        return $this->getKey();
    }
    public function getJWTCustomClaims()
    {
        return [];
    }
}
